@@ -49,6 +49,7 @@ out.
 #include <wx/filefn.h>
 #include <wx/ffile.h>
 #include <wx/log.h>
+#include <wx/math.h>
 
 #include "BlockFile.h"
 #include "Internat.h"
@@ -306,6 +307,10 @@ static void ComputeMinMax256(float *summary256,
          max = summary256[3*i+1];
       else if (!(summary256[3*i+1] <= max))
          bad++;
+      if (wxIsNaN(summary256[3*i+2]))
+         bad++;
+      if (summary256[3*i+2] < -1 || summary256[3*i+2] > 1)
+         bad++;
    }
 
    *outMin = min;
