@@ -16,14 +16,18 @@
 
 // Uh, this is really a namespace rather than a class,
 // since all the functions are static.
-class FileNames
+class AUDACITY_DLL_API FileNames
 {
 public:
    static wxString MkDir(const wxString &Str);
    static wxString TempDir();
    static wxString DataDir();
    static wxString AutoSaveDir();
+   static wxString HtmlHelpDir();
+   static wxString HtmlHelpIndexFile();
    static wxString ChainDir();
+   static wxString NRPDir();
+   static wxString NRPFile();
    static wxString ThemeDir();
    static wxString ThemeComponentsDir();
    static wxString ThemeCachePng();
