@@ -21,6 +21,7 @@
 *//*******************************************************************/
 
 #include "Audacity.h"
+#include "AudacityApp.h"
 #include "TrackArtist.h"
 #include "float_cast.h"
 
@@ -145,6 +146,19 @@ void TrackArtist::DrawTracks(TrackList * tracks,
       }
    }
 
+#if defined(DEBUG_CLIENT_AREA)
+   // Change the +0 to +1 or +2 to see the bounding box
+   mInsetLeft = 1+0; mInsetTop = 5+0; mInsetRight = 6+0; mInsetBottom = 2+0;
+
+   // This just show what the passed in rectanges enclose
+   dc.SetPen(wxColour(*wxGREEN));
+   dc.SetBrush(*wxTRANSPARENT_BRUSH);
+   dc.DrawRectangle(r);
+   dc.SetPen(wxColour(*wxBLUE));
+   dc.SetBrush(*wxTRANSPARENT_BRUSH);
+   dc.DrawRectangle(clip);
+#endif
+
    t = iter.First();
    bool linkFlag = false;
    bool muted = false;
@@ -166,6 +180,15 @@ void TrackArtist::DrawTracks(TrackList * tracks,
 
       trackRect.height = t->GetHeight();
 
+#if defined(DEBUG_CLIENT_AREA)
+      // Filled rectangle to show the interior of the client area
+      wxRect zr = trackRect;
+      zr.x+=1; zr.y+=5; zr.width-=7; zr.height-=7;
+      dc.SetPen(*wxCYAN_PEN);
+      dc.SetBrush(*wxRED_BRUSH);
+      dc.DrawRectangle(zr);
+#endif
+
       stereoTrackRect = trackRect;
 
       // For various reasons, the code will break if we display one
@@ -239,12 +262,19 @@ void TrackArtist::DrawTracks(TrackList * tracks,
 
 void TrackArtist::DrawVRuler(Track *t, wxDC * dc, wxRect & r)
 {
-   if (t->GetKind() == Track::Wave
-       && ((WaveTrack *) t)->GetDisplay() == 0) {
-      // Waveform
+   // All waves have a ruler in the info panel
+   // The ruler needs a bevelled surround.
+   if (t->GetKind() == Track::Wave )
+   {
       wxRect bev = r;
       bev.Inflate(-1, -1);
-      AColor::Bevel(*dc, true, bev);
+      bev.width  +=1;
+      AColor::BevelTrackInfo(*dc, true, bev);
+   }
+
+   if (t->GetKind() == Track::Wave
+       && ((WaveTrack *) t)->GetDisplay() == WaveTrack::WaveformDisplay) {
+      // Waveform
       float min, max;
 
       ((WaveTrack *)t)->GetDisplayBounds(&min, &max);
@@ -258,11 +288,8 @@ void TrackArtist::DrawVRuler(Track *t, wxDC * dc, wxRect & r)
    }
 
    if (t->GetKind() == Track::Wave
-       && ((WaveTrack *) t)->GetDisplay() == 1) {
+       && ((WaveTrack *) t)->GetDisplay() == WaveTrack::WaveformDBDisplay) {
       // Waveform (db)
-      wxRect bev = r;
-      bev.Inflate(-1, -1);
-      AColor::Bevel(*dc, true, bev);
       vruler->SetUnits(wxT(""));
 
       float dBr = gPrefs->Read(wxT("/GUI/EnvdBRange"), ENV_DB_RANGE);
@@ -304,12 +331,8 @@ void TrackArtist::DrawVRuler(Track *t, wxDC * dc, wxRect & r)
    }
 
    if (t->GetKind() == Track::Wave
-       && ((WaveTrack *) t)->GetDisplay() == 2) {
+       && ((WaveTrack *) t)->GetDisplay() == WaveTrack::SpectrumDisplay) {
       // Spectrum
-      wxRect bev = r;
-      bev.Inflate(-1, -1);
-      AColor::Bevel(*dc, true, bev);
-
       if (r.height < 60)
          return;
 
@@ -347,13 +370,11 @@ void TrackArtist::DrawVRuler(Track *t, wxDC * dc, wxRect & r)
    }
 
    if (t->GetKind() == Track::Wave
-       && ((WaveTrack *) t)->GetDisplay() == 3) {
+       && ((WaveTrack *) t)->GetDisplay() == WaveTrack::PitchDisplay) {
       // Pitch
-      wxRect bev = r;
-      bev.Inflate(-1, -1);
-      AColor::Bevel(*dc, true, bev);
    }
 
+   // The note track isn't drawing a ruler at all!
    if (t->GetKind() == Track::Note) {
 
       dc->SetPen(*wxTRANSPARENT_PEN);
@@ -521,11 +542,11 @@ int TrackArtist::GetWaveYPosUnclipped(float value, int height, bool dB,
 
 void TrackArtist::DrawNegativeOffsetTrackArrows(wxDC &dc, wxRect &r)
 {
-   // Draws two white arrows on the left side of the track to
+   // Draws two black arrows on the left side of the track to
    // indicate the user that the track has been time-shifted
    // to the left beyond t=0.0.
 
-   dc.SetPen(*wxWHITE_PEN);
+   dc.SetPen(*wxBLACK_PEN);
    dc.DrawLine(r.x + 2, r.y + 6, r.x + 8, r.y + 6);
    dc.DrawLine(r.x + 2, r.y + 6, r.x + 6, r.y + 2);
    dc.DrawLine(r.x + 2, r.y + 6, r.x + 6, r.y + 10);
@@ -600,13 +621,20 @@ void TrackArtist::DrawWaveformBackground(wxDC &dc, wxRect r,
       for(x=0; x<r.width; x++)
          sel[x] = (ssel0 <= where[x] && where[x + 1] < ssel1);
 
+      int mid = (int) ((zoomMax/(zoomMax-zoomMin))*r.height);
+
       GetColour(blankPen, &r0, &g0, &b0);
       GetColour(unselectedPen, &r1, &g1, &b1);
       GetColour(selectedPen, &r2, &g2, &b2);
       for(y=0; y<r.height; y++) {
          for(x=0; x<r.width; x++) {
-            if (y < maxtop[x] || y >= minbot[x] ||
-                (y >= mintop[x] && y < maxbot[x])) {
+            if (y == mid) {
+               *imageBuffer++ = 0;
+               *imageBuffer++ = 0;
+               *imageBuffer++ = 0;
+            }
+            else if (y < maxtop[x] || y > minbot[x] ||
+                (y > mintop[x] && y < maxbot[x])) {
                *imageBuffer++ = r0;
                *imageBuffer++ = g0;
                *imageBuffer++ = b0;
@@ -797,29 +825,13 @@ void TrackArtist::DrawMinMaxRMS(wxDC &dc, wxRect r, uchar *imageBuffer,
 
       // JKC: This adjustment to h1[] and h2[] ensures that the drawn
       // waveform is continuous.
-      if( x>0 )
-      {
-         if( h1[x] < h2[x-1] )
+      if (x > 0) {
+         if (h1[x] < h2[x-1])
             h1[x]=h2[x-1]-1;
-         if( h2[x] > h1[x-1] )
+         if (h2[x] > h1[x-1])
             h2[x]=h1[x-1]+1;
       }
 
-      if (imageBuffer) {
-         // Make the height at least one, otherwise the waveform can
-         // shrink to nothing.  This scenario is handled differently
-         // if we use wx to draw, instead of the image buffer - see
-         // MM comment below.
-         if( h1[x] <= h2[x]) {
-            if (h2[x] < r.height-1)
-               h1[x] = h2[x] + 1;
-            else {
-               h1[x] = h2[x];
-               h2[x]--;
-            }
-         }
-      }
-
       // Make sure the rms isn't larger than the waveform
       // min/max
       if (r1[x] > h1[x]-1)
@@ -843,7 +855,7 @@ void TrackArtist::DrawMinMaxRMS(wxDC &dc, wxRect r, uchar *imageBuffer,
                *imageBuffer++ = gr;
                *imageBuffer++ = br;
             }
-            else if (y >= h2[x] && y < h1[x]) {
+            else if (y >= h2[x] && y < h1[x]+1) {
                *imageBuffer++ = rs;
                *imageBuffer++ = gs;
                *imageBuffer++ = bs;               
@@ -902,7 +914,7 @@ void TrackArtist::DrawEnvLine(wxDC &dc, wxRect r, int x, int y, bool top)
                      r.x + x, r.y + y + 3);
       else
          dc.DrawLine(r.x + x, r.y + y - 3,
-                     r.x + x, r.y + y );
+                     r.x + x, r.y + y);
    }
 }
 
@@ -1093,17 +1105,12 @@ void TrackArtist::DrawClipWaveform(WaveTrack* track, WaveClip* clip,
    wxRect drawRect = mid;
 
    #if BUFFERED_DRAWING
-
    drawRect.x = 0;
    drawRect.y = 0;
    wxImage *image = new wxImage(drawRect.width, drawRect.height);
    imageBuffer = image->GetData();
    #endif
 
-
-
-
-
    // Get the values of the envelope corresponding to each pixel
    // in the display, and use these to compute the height of the
    // track at each pixel
@@ -1119,20 +1126,17 @@ void TrackArtist::DrawClipWaveform(WaveTrack* track, WaveClip* clip,
    DrawWaveformBackground(dc, drawRect, imageBuffer, where, ssel0, ssel1,
                           envValues, zoomMin, zoomMax, dB, drawEnvelope);
 
-   float trackmin, trackmax;
-   track->GetDisplayBounds(&trackmin, &trackmax);
-
    //OK, the display bounds are between min and max, which
    //is spread across r.height.  Draw the line at the proper place.
 
-   if(trackmin < 0 && trackmax > 0)
-   {
-         float height = (trackmax/(trackmax-trackmin))*mid.height;
-         dc.SetPen(*wxBLACK_PEN);
-         dc.DrawLine(mid.x, (int) (mid.y+height), mid.x+mid.width,
-               (int) (mid.y+height));
+   #if !BUFFERED_DRAWING
+   if (zoomMin < 0 && zoomMax > 0) {
+      float height = (zoomMax/(zoomMax-zoomMin))*mid.height;
+      dc.SetPen(*wxBLACK_PEN);
+      dc.DrawLine(mid.x, (int) (mid.y+height), mid.x+mid.width,
+            (int) (mid.y+height));
    }
-
+   #endif
 
    if (!showIndividualSamples)
       DrawMinMaxRMS(dc, drawRect, imageBuffer, zoomMin, zoomMax,
@@ -1182,6 +1186,35 @@ void TrackArtist::DrawClipWaveform(WaveTrack* track, WaveClip* clip,
       }
    }
 
+   // Draw clipping indicators if requested
+   bool showclipping = gPrefs->Read(wxT("/GUI/ShowClipping"), 0L)!=0;
+   if (showclipping) {
+      dc.SetPen(AColor::clippingPen);
+
+      sampleCount s0 = (sampleCount) lrint(t0 * rate);
+      sampleCount slen = (sampleCount) lrint(mid.width * rate / pps);
+      sampleCount snSamples = clip->GetNumSamples(); 
+
+      if (s0 + slen > snSamples) {
+         slen = snSamples - s0;
+      }
+
+      float *buffer = new float[slen];
+      clip->GetSamples((samplePtr)buffer, floatSample, s0, slen);
+
+      for (sampleCount s = 0; s < slen; s++) {
+         float v = floor(buffer[s]);
+         if (buffer[s] <= -MAX_AUDIO) {
+            int x = lrint((s / rate + s0 / rate - t0) * pps);
+            dc.DrawLine(mid.x + x, mid.y + (mid.height / 2), mid.x + x, mid.y + mid.height);
+         }
+         else if (buffer[s] >= MAX_AUDIO) {
+            int x = lrint((s / rate + s0 / rate - t0) * pps);
+            dc.DrawLine(mid.x + x, mid.y, mid.x + x, mid.y + (mid.height / 2));
+         }
+      }
+      delete [] buffer;
+   }
 
    // Draw arrows on the left side if the track extends to the left of the
    // beginning of time.  :)
@@ -1211,10 +1244,9 @@ void TrackArtist::DrawClipWaveform(WaveTrack* track, WaveClip* clip,
    dc.SetPen(*wxGREY_PEN);
    if (tpre < 0)
       dc.DrawLine(mid.x-1, mid.y, mid.x-1, mid.y+r.height);
-   if (tpost >= t1)
+   if (tpost > t1)
       dc.DrawLine(mid.x+mid.width, mid.y, mid.x+mid.width, mid.y+r.height);
 
-
 #if PROFILE_WAVEFORM
    gettimeofday(&tv1, NULL);
    double elapsed =
@@ -1251,7 +1283,7 @@ void TrackArtist::DrawTimeSlider(WaveTrack *track,
 
    int xLeft = rightwards ? (r.x +border -2) : (r.x + r.width + 1 - (border+width));
    int yTop  = r.y+border;
-   int yBot  = r.y+r.height-border;
+   int yBot  = r.y+r.height-border-1;
 
    AColor::Light(&dc, false);
    dc.DrawLine( xLeft,       yBot-leftTaper, xLeft,       yTop+leftTaper );
@@ -1290,7 +1322,7 @@ void TrackArtist::DrawSpectrum(WaveTrack *track,
    dc.SetBrush(blankBrush);
    dc.DrawRectangle(r);
 
-   if(!viewInfo->bUpdateSpectrogram && viewInfo->bIsPlaying)
+   if(!viewInfo->bUpdateTrackIndicator && viewInfo->bIsPlaying)
    {
       // BG: Draw (undecorated) waveform instead of spectrum
       DrawWaveform(track, dc, r, viewInfo, false, false, false, false, false);
