@@ -47,6 +47,7 @@
 #include "../WaveTrack.h"
 #include "../Prefs.h"
 #include "../Project.h"
+#include "../FileNames.h"
 
 #include <math.h>
 
@@ -70,6 +71,7 @@
 #include <wx/textctrl.h>
 
 #include "../AudacityApp.h"
+#include "../PlatformCompatibility.h"
 
 EffectNoiseRemoval::EffectNoiseRemoval()
 {
@@ -83,7 +85,7 @@ EffectNoiseRemoval::EffectNoiseRemoval()
    gPrefs->Read(wxT("/CsPresets/NoiseAttackDecayTime"),
                 &mAttackDecayTime, 0.15);
 
-   mMinSignalTime = 0.05;
+   mMinSignalTime = 0.05f;
    mHasProfile = false;
    mDoProfile = true;
 
@@ -116,12 +118,17 @@ void EffectNoiseRemoval::CleanSpeechMayReadNoisegate()
          return;
       }
    }
+
    // Try to open the file.
-   wxString filename = wxT("noisegate.nrp");
-   // if file doesn't exist, return quietly.
-   if( !wxFile::Exists( filename ))
+   if( !wxDirExists( FileNames::NRPDir() ))
       return;
-   wxFFile noiseGateFile(filename, wxT("rb"));
+
+   // if file doesn't exist, return quietly.
+   wxString fileName = FileNames::NRPFile();
+   if( !wxFileExists( fileName ))
+      return;
+
+   wxFFile noiseGateFile(fileName, wxT("rb"));
    bool flag = noiseGateFile.IsOpened();
    if (flag != true)
       return;
@@ -131,8 +138,8 @@ void EffectNoiseRemoval::CleanSpeechMayReadNoisegate()
    int count = noiseGateFile.Read(mNoiseThreshold, expectedCount);
    noiseGateFile.Close();
    if (count == expectedCount) {
-      for (int i = halfWindowSize; i < mWindowSize; ++i) {
-         mNoiseThreshold[i] = float(0.0);  // only half filled by Read
+      for (int i = halfWindowSize; i < mSpectrumSize; ++i) {
+         mNoiseThreshold[i] = float(0.0);  // only partly filled by Read?
       }
       mHasProfile = true;
       mDoProfile = false;
@@ -144,7 +151,34 @@ void EffectNoiseRemoval::CleanSpeechMayWriteNoiseGate()
    AudacityProject * project = GetActiveProject();
    if( !project || !project->GetCleanSpeechMode() )
       return;
-   wxFFile noiseGateFile(wxT("noisegate.nrp"), wxT("wb"));
+
+   // code borrowed from ThemeBase::SaveComponents() - MJS
+   // IF directory doesn't exist THEN create it
+   if( !wxDirExists( FileNames::NRPDir() ))
+   {
+      /// \bug 1 in wxWidgets documentation; wxMkDir returns false if 
+      /// directory didn't exist, even if it successfully creates it.
+      /// so we create and then test if it exists instead.
+      /// \bug 2 in wxWidgets documentation; wxMkDir has only one argument
+      /// under MSW
+#ifdef __WXMSW__
+      wxMkDir( FileNames::NRPDir().fn_str() );
+#else
+      wxMkDir( FileNames::NRPDir().fn_str(), 0700 );
+#endif
+      if( !wxDirExists( FileNames::NRPDir() ))
+      {
+         wxMessageBox(
+            wxString::Format( 
+            _("Could not create directory:\n  %s"),
+               FileNames::NRPDir().c_str() ));
+         return;
+      }
+   }
+
+   wxString fileName = FileNames::NRPFile();
+   fileName = PlatformCompatibility::GetLongFileName(fileName);
+   wxFFile noiseGateFile(fileName, wxT("wb"));
    bool flag = noiseGateFile.IsOpened();
    if (flag == true) {
       int expectedCount = (mWindowSize / 2) * sizeof(float);
@@ -152,6 +186,12 @@ void EffectNoiseRemoval::CleanSpeechMayWriteNoiseGate()
       noiseGateFile.Write(mNoiseThreshold, expectedCount);
       noiseGateFile.Close();
    }
+   else {
+      wxMessageBox(
+         wxString::Format( 
+         _("Could not open file:\n  %s"), fileName.c_str() ));
+      return;
+   }
 }
 
 #define MAX_NOISE_LEVEL  30
@@ -180,7 +220,9 @@ bool EffectNoiseRemoval::PromptUser()
 
    if( !mHasProfile )
    {
-      CleanSpeechMayReadNoisegate();
+      AudacityProject * p = GetActiveProject();
+      if (p->GetCleanSpeechMode())
+         CleanSpeechMayReadNoisegate();
    }
 
    // We may want to twiddle the levels if we are setting
@@ -232,7 +274,7 @@ bool EffectNoiseRemoval::Process()
    // This should only happen in CleanSpeech.
    if(!mDoProfile && !mHasProfile) {
       wxMessageBox(
-        _("Attempt to run Noise Removal without a noise profile\n."));
+        _("Attempt to run Noise Removal without a noise profile.\n"));
       return false;
    }
 
@@ -240,7 +282,10 @@ bool EffectNoiseRemoval::Process()
 
    // This same code will both remove noise and profile it,
    // depending on 'mDoProfile'
-   TrackListIterator iter(mWaveTracks);
+   this->CopyInputWaveTracks(); // Set up m_pOutputWaveTracks.
+   bool bGoodResult = true;
+
+   TrackListIterator iter(m_pOutputWaveTracks);
    WaveTrack *track = (WaveTrack *) iter.First();
    int count = 0;
    while (track) {
@@ -256,21 +301,24 @@ bool EffectNoiseRemoval::Process()
 
          if (!ProcessOne(count, track, start, len)) {
             Cleanup();
-            return false;
+            bGoodResult = false;
+            break;
          }
       }
       track = (WaveTrack *) iter.Next();
       count++;
    }
 
-   if (mDoProfile) {
+   if (bGoodResult && mDoProfile) {
       CleanSpeechMayWriteNoiseGate();
       mHasProfile = true;
       mDoProfile = false;
    }
 
-   Cleanup();
-   return true;
+   if (bGoodResult)
+      Cleanup();
+   this->ReplaceProcessedWaveTracks(bGoodResult); 
+   return bGoodResult;
 }
 
 void EffectNoiseRemoval::ApplyFreqSmoothing(float *spec)
