@@ -52,6 +52,7 @@ effects from this one class.
 #include "../../AudacityApp.h"
 #include "../../LabelTrack.h"
 #include "../../Internat.h"
+#include "../../ShuttleGui.h"
 
 #include "Nyquist.h"
 
@@ -109,9 +110,7 @@ double EffectNyquist::GetCtrlValue(wxString s)
       return ((WaveTrack *)iter.First())->GetRate();
    }
    else {
-      double d;
-      s.ToDouble(&d);
-      return d;
+      return Internat::CompatibleToDouble(s);
    }
 }
 
@@ -328,7 +327,7 @@ bool EffectNyquist::PromptUser()
       if (result == wxID_CANCEL)
          return false;
 
-      if (result == wxID_MORE)
+      if (result == eDebugID)
          mDebug = true;
       else
          mDebug = false;
@@ -383,7 +382,7 @@ bool EffectNyquist::PromptUser()
    if (result == wxID_CANCEL)
       return false;
    
-   if (result == wxID_MORE)
+   if (result == eDebugID)
       mDebug = true;
    else
       mDebug = false;
@@ -395,7 +394,8 @@ bool EffectNyquist::Process()
 {
    bool success = true;
    
-   TrackListIterator iter(mWaveTracks);
+   this->CopyInputWaveTracks(); // Set up m_pOutputWaveTracks.
+   TrackListIterator iter(m_pOutputWaveTracks);
    mCurTrack[0] = (WaveTrack *) iter.First();
    mOutputTime = mT1 - mT0;
    mCount = 0;
@@ -412,7 +412,8 @@ bool EffectNyquist::Process()
                wxMessageBox(_("Sorry, cannot apply effect on stereo tracks where the tracks don't match."), 
                             wxT("Nyquist"),
                             wxOK | wxCENTRE, mParent);
-               return false;
+               success = false;
+               goto finish;
             }
             mCurStart[1] = mCurTrack[1]->TimeToLongSamples(mT0);
          }
@@ -443,6 +444,7 @@ bool EffectNyquist::Process()
       dlog.ShowModal();
    }
 
+   this->ReplaceProcessedWaveTracks(success); 
    return success;
 }
 
@@ -715,7 +717,7 @@ bool EffectNyquist::ProcessOne()
 BEGIN_EVENT_TABLE(NyquistDialog, wxDialog)
    EVT_BUTTON(wxID_OK, NyquistDialog::OnOk)
    EVT_BUTTON(wxID_CANCEL, NyquistDialog::OnCancel)
-   EVT_BUTTON(wxID_MORE, NyquistDialog::OnDebug)
+   EVT_BUTTON(eDebugID, NyquistDialog::OnDebug)
    EVT_COMMAND_RANGE(ID_NYQ_SLIDER, ID_NYQ_SLIDER+99,
                      wxEVT_COMMAND_SLIDER_UPDATED, NyquistDialog::OnSlider)
    EVT_COMMAND_RANGE(ID_NYQ_TEXT, ID_NYQ_TEXT+99,
@@ -734,8 +736,6 @@ NyquistDialog::NyquistDialog(wxWindow * parent, wxWindowID id,
    mInHandler = true; // prevents race condition on MSW
 
    wxBoxSizer *mainSizer = new wxBoxSizer(wxVERTICAL);
-   wxBoxSizer *hSizer;
-   wxButton   *button;
 
    if (info.Length() > 0) {
       wxControl  *item;
@@ -809,7 +809,11 @@ NyquistDialog::NyquistDialog(wxWindow * parent, wxWindowID id,
                    wxALIGN_CENTER_VERTICAL | wxALL, 5);
       }
          
-      if( ctrl->type != NYQ_CTRL_CHOICE )
+      if( ctrl->type == NYQ_CTRL_CHOICE )
+      {
+         grid->Add( 10, 10 );
+      }
+      else
       {
          item = new wxStaticText(this, -1, ctrl->label);
          grid->Add(item, 0, wxALIGN_LEFT | 
@@ -818,19 +822,7 @@ NyquistDialog::NyquistDialog(wxWindow * parent, wxWindowID id,
    }
    mainSizer->Add(grid, 0, wxALIGN_CENTRE | wxALL, 5);
 
-   hSizer = new wxBoxSizer(wxHORIZONTAL);
-
-   button = new wxButton(this, wxID_CANCEL, _("&Cancel"));
-   hSizer->Add(button, 0, wxALIGN_CENTRE | wxALL, 5);
-
-   button = new wxButton(this, wxID_MORE, _("&Debug"));
-   hSizer->Add(button, 0, wxALIGN_CENTRE | wxALL, 5);
-
-   button = new wxButton(this, wxID_OK, _("&OK"));
-   button->SetDefault();
-   hSizer->Add(button, 0, wxALIGN_CENTRE | wxALL, 5);
-
-   mainSizer->Add(hSizer, 0, wxALIGN_CENTRE | wxALL, 5);
+   mainSizer->Add(CreateStdButtonSizer(this, eDebugButton|eCancelButton|eOkButton), 0, wxEXPAND);
 
    mInHandler = false;
 
@@ -866,11 +858,11 @@ void NyquistDialog::OnSlider(wxCommandEvent & /* event */)
       wxString valStr;
       if (ctrl->type == NYQ_CTRL_REAL) {
          if (ctrl->high - ctrl->low < 1)
-            valStr.Printf(wxT("%.3f"), ctrl->val);
+            valStr = Internat::ToDisplayString(ctrl->val, 3);
          else if (ctrl->high - ctrl->low < 10)
-            valStr.Printf(wxT("%.2f"), ctrl->val);
+            valStr = Internat::ToDisplayString(ctrl->val, 2);
          else if (ctrl->high - ctrl->low < 100)
-            valStr.Printf(wxT("%.1f"), ctrl->val);
+            valStr = Internat::ToDisplayString(ctrl->val, 1);
          else
             valStr.Printf(wxT("%d"), (int)floor(ctrl->val + 0.5));
       }
@@ -922,14 +914,16 @@ void NyquistDialog::OnText(wxCommandEvent &event)
       wxSlider *slider = (wxSlider *)FindWindow(ID_NYQ_SLIDER + ctrlId);
       wxASSERT(slider);
 
-      ctrl->valStr.ToDouble(&ctrl->val);
-      int pos = (int)floor((ctrl->val - ctrl->low) /
-                           (ctrl->high - ctrl->low) * ctrl->ticks + 0.5);
-      if (pos < 0)
-         pos = 0;
-      if (pos > ctrl->ticks)
-         pos = ctrl->ticks;
-      slider->SetValue(pos);
+      if (ctrl->valStr.ToDouble(&ctrl->val))
+      {
+         int pos = (int)floor((ctrl->val - ctrl->low) /
+                              (ctrl->high - ctrl->low) * ctrl->ticks + 0.5);
+         if (pos < 0)
+            pos = 0;
+         if (pos > ctrl->ticks)
+            pos = ctrl->ticks;
+         slider->SetValue(pos);
+      }
    }   
 
    mInHandler = false;   
@@ -951,7 +945,7 @@ void NyquistDialog::OnDebug(wxCommandEvent & /* event */)
 {
    // Transfer data
 
-   EndModal(wxID_MORE);
+   EndModal(eDebugID);
 }
 
 /**********************************************************/
@@ -959,7 +953,7 @@ void NyquistDialog::OnDebug(wxCommandEvent & /* event */)
 BEGIN_EVENT_TABLE(NyquistInputDialog, wxDialog)
    EVT_BUTTON(wxID_OK, NyquistInputDialog::OnOk)
    EVT_BUTTON(wxID_CANCEL, NyquistInputDialog::OnCancel)
-   EVT_BUTTON(wxID_MORE, NyquistInputDialog::OnDebug)
+   EVT_BUTTON(eDebugID, NyquistInputDialog::OnDebug)
 END_EVENT_TABLE()
 
 NyquistInputDialog::NyquistInputDialog(wxWindow * parent, wxWindowID id,
@@ -969,8 +963,6 @@ NyquistInputDialog::NyquistInputDialog(wxWindow * parent, wxWindowID id,
    :wxDialog(parent, id, title)
 {
    wxBoxSizer *mainSizer = new wxBoxSizer(wxVERTICAL);
-   wxBoxSizer *hSizer;
-   wxButton   *button;
    wxControl  *item;
 
    item = new wxStaticText(this, -1, prompt);
@@ -982,19 +974,8 @@ NyquistInputDialog::NyquistInputDialog(wxWindow * parent, wxWindowID id,
                                  wxTE_MULTILINE);
    mainSizer->Add(mCommandText, 0, wxALIGN_LEFT | wxALL, 10);
 
-   hSizer = new wxBoxSizer(wxHORIZONTAL);
-
-   button = new wxButton(this, wxID_CANCEL, _("&Cancel"));
-   hSizer->Add(button, 0, wxALIGN_CENTRE | wxALL, 5);
-
-   button = new wxButton(this, wxID_MORE, _("&Debug"));
-   hSizer->Add(button, 0, wxALIGN_CENTRE | wxALL, 5);
-
-   button = new wxButton(this, wxID_OK, _("OK"));
-   hSizer->Add(button, 0, wxALIGN_CENTRE | wxALL, 5);
-
-   mainSizer->Add(hSizer, 0, wxALIGN_CENTRE |
-                  wxLEFT | wxBOTTOM | wxRIGHT, 5);
+   // Debug, OK, & Cancel buttons
+   mainSizer->Add(CreateStdButtonSizer(this, eDebugButton|eCancelButton|eOkButton), 0, wxEXPAND);
 
    SetAutoLayout(true);
    SetSizer(mainSizer);
@@ -1023,7 +1004,7 @@ void NyquistInputDialog::OnDebug(wxCommandEvent & /* event */)
 {
    // Transfer data
 
-   EndModal(wxID_MORE);
+   EndModal(eDebugID);
 }
 
 
