@@ -100,7 +100,6 @@ ExportMultiple::ExportMultiple(AudacityProject *project)
    PopulateOrExchange(S);
    mInitialized = true;
 
-   GetSizer()->AddSpacer(5);
    Layout();
    Fit();
    SetMinSize(GetSize());
@@ -175,6 +174,8 @@ int ExportMultiple::ShowModal()
 
 void ExportMultiple::PopulateOrExchange(ShuttleGui& S)
 {
+   wxString name = mProject->GetName();
+
    S.SetBorder(5);
    S.StartMultiColumn(4, true);
    {
@@ -232,8 +233,7 @@ void ExportMultiple::PopulateOrExchange(ShuttleGui& S)
                mFirstFileLabel = S.AddVariableText(_("First file name:"), true);
                mFirstFileName = S.Id(FirstFileNameID)
                   .TieTextBox(wxT(""),
-                              wxT("/Export/MultipleFirstName"),
-                              wxT(""),
+                              name,
                               30);
             }
             S.EndHorizontalLay();
@@ -276,8 +276,7 @@ void ExportMultiple::PopulateOrExchange(ShuttleGui& S)
                mPrefixLabel = S.AddVariableText(_("File name prefix:"), true);
                mPrefix = S.Id(PrefixID)
                   .TieTextBox(wxT(""),
-                              wxT("/Export/MultiplePrefix"),
-                              wxT(""),
+                              name,
                               30);
             }
             S.EndHorizontalLay();
@@ -295,19 +294,11 @@ void ExportMultiple::PopulateOrExchange(ShuttleGui& S)
          .AddCheckBox(_("Overwrite existing files"), wxT("true"));
    }
    S.EndHorizontalLay();
-      
-   S.StartHorizontalLay(wxALIGN_CENTER, false);
-   {
-#if defined(__WXGTK20__) || defined(__WXMAC__)
-      S.Id(wxID_CANCEL).AddButton(_("&Cancel"));
-      mExport = S.Id(wxID_OK).AddButton(_("E&xport"));
-#else
-      mExport = S.Id(wxID_OK).AddButton(_("E&xport"));
-      S.Id(wxID_CANCEL).AddButton(_("&Cancel"));
-#endif
-      mExport->SetDefault();
-   }
-   S.EndHorizontalLay();
+
+   S.AddStandardButtons();
+   mExport = (wxButton *)wxWindow::FindWindowById(wxID_OK, this);
+   mExport->SetLabel(_("E&xport"));
+
 }
 
 void ExportMultiple::EnableControls()
@@ -439,20 +430,18 @@ void ExportMultiple::OnExport(wxCommandEvent& event)
       Tags *tags = mProject->GetTags();
 
       if (tags->IsEmpty()) {
-         wxString saveTitle = tags->GetTitle();
-         int saveTrackNumber = tags->GetTrackNumber();
-         tags->SetTitle(wxT("(automatic)"));
-         tags->SetTrackNumber(0);
+         tags->SetTag(TAG_TITLE, wxT("(automatic)"));
+         tags->SetTag(TAG_TRACK, wxT("0"));
          tags->AllowEditTitle(false);
          tags->AllowEditTrackNumber(false);
          bool rval = tags->ShowEditDialog(mProject,
-                                          _("Edit the ID3 tags for all MP3 files"),
+                                          _("Edit the metadata"),
                                           true);
+         tags->SetTag(TAG_TITLE, wxT(""));
+         tags->SetTag(TAG_TRACK, wxT(""));
          tags->AllowEditTitle(true);
          tags->AllowEditTrackNumber(true);
          if (!rval) {
-            tags->SetTitle(saveTitle);
-            tags->SetTrackNumber(saveTrackNumber);
             return;
          }
       }
@@ -520,7 +509,7 @@ bool ExportMultiple::ExportMultipleByLabel(bool byName, wxString prefix)
    for (tr = mIterator.First(mTracks); tr != NULL; tr = mIterator.Next()) {
 
       // Only want wave tracks
-      if (!tr->GetKind() == Track::Wave) {
+      if (tr->GetKind() != Track::Wave) {
          continue;
       }
 
@@ -762,19 +751,30 @@ bool ExportMultiple::DoExport(bool stereo,
    }
 
    // If the format supports tags, then set the name and track number
+   Tags *tags = NULL;
+   wxString oldTitle;
+   wxString oldTrack;
    if (mPlugins[mFormatIndex]->GetCanMetaData()) {
-      Tags *tags = mProject->GetTags();
-      tags->SetTitle(name);
-      tags->SetTrackNumber(trackNumber);
+      tags = mProject->GetTags();
+      oldTitle = tags->GetTag(TAG_TITLE);
+      oldTrack = tags->GetTag(TAG_TRACK);
+      tags->SetTag(TAG_TITLE, name);
+      tags->SetTag(TAG_TRACK, trackNumber);
    }
 
    // Call the format export routine
-   return mPlugins[mFormatIndex]->Export(mProject,
-                                         stereo ? 2 : 1,
-                                         fn.GetFullPath(),
-                                         selectedOnly,
-                                         t0,
-                                         t1);
+   bool rc = mPlugins[mFormatIndex]->Export(mProject,
+                                            stereo ? 2 : 1,
+                                            fn.GetFullPath(),
+                                            selectedOnly,
+                                            t0,
+                                            t1);
+   if (tags) {
+      tags->SetTag(TAG_TITLE, oldTitle);
+      tags->SetTag(TAG_TRACK, oldTrack);
+   }
+
+   return rc;
 }
 
 // Indentation settings for Vim and Emacs and unique identifier for Arch, a
