@@ -34,6 +34,7 @@
 *//******************************************************************/
 
 #include "../Audacity.h"
+#include "../AudacityApp.h"
 
 #include <wx/defs.h>
 #include <wx/dcmemory.h>
@@ -46,6 +47,10 @@
 #include <wx/tooltip.h>
 #include <wx/msgdlg.h>
 
+#if defined(__WXMAC__)
+#include <wx/mac/uma.h>
+#endif
+
 #include <math.h>
 
 #include "Meter.h"
@@ -60,6 +65,7 @@
 
 #include "../Theme.h"
 #include "../AllThemeResources.h"
+#include "../Experimental.h"
 
 //
 // The Meter passes itself messages via this queue so that it can
@@ -470,7 +476,7 @@ void Meter::UpdateDisplay(int numChannels, int numFrames, float *sampleData)
          // Send the number of peaked samples at the head and tail,
          // in case there's a run of peaked samples that crosses
          // block boundaries
-         if (fabs(sptr[j])>=1.0) {
+         if (fabs(sptr[j])>=MAX_AUDIO) {
             if (msg.headPeakCount[j]==i)
                msg.headPeakCount[j]++;
             msg.tailPeakCount[j]++;
@@ -555,6 +561,17 @@ void Meter::OnMeterUpdate(wxTimerEvent &evt)
       RepaintBarsNow();
 }
 
+float Meter::GetMaxPeak()
+{
+   int j;
+   float maxPeak = 0.;
+
+   for(j=0; j<mNumBars; j++)
+      maxPeak = mBar[j].peak > maxPeak ? mBar[j].peak : maxPeak;
+
+   return(maxPeak);
+}
+
 wxFont Meter::GetFont()
 {
    int fontSize = 10;
@@ -572,10 +589,10 @@ void Meter::ResetBar(MeterBar *b, bool resetClipping)
    b->peakHold = 0.0;
    b->peakHoldTime = 0.0;
    if (resetClipping)
-      {
+   {
       b->clipping = false;
       b->peakPeakHold =0.0;
-      }
+   }
    b->tailPeakCount = 0;
 }
 
@@ -746,6 +763,13 @@ void Meter::HandlePaint(wxDC &dc)
       HandleLayout();
 
 #ifndef USE_AQUA_THEME
+#ifdef EXPERIMENTAL_THEMING
+   if( !mMeterDisabled )
+   {
+      mBkgndBrush.SetColour( GetParent()->GetBackgroundColour() );
+   }
+#endif
+
    dc.SetPen(*wxTRANSPARENT_PEN);
    dc.SetBrush(mBkgndBrush);
    dc.DrawRectangle(0, 0, mWidth, mHeight);
@@ -1032,16 +1056,26 @@ void Meter::OnFloat(wxCommandEvent &evt)
 
 void Meter::OnPreferences(wxCommandEvent &evt)
 {
-   long refreshRate = 0;
-   if (-1 <  (refreshRate = ::wxGetNumberFromUser
-              (_("This determines how often the meter is refreshed.\nIf you have a slower PC you may want to select a\nlower refresh rate (30 per second or lower), so that\naudio qualtiy is not affected by the meter display."),
-               _("Meter refresh rate per second [1-100]: "),
-               _("Meter Preferences"),
-               mMeterRefreshRate, 1, 100)))
-      mMeterRefreshRate = refreshRate;
-   gPrefs->Write(wxT("/Meter/MeterRefreshRate"), mMeterRefreshRate);
+   wxNumberEntryDialog
+      d(this,
+        _("This determines how often the meter is refreshed.\nIf you have a slower PC you may want to select a\nlower refresh rate (30 per second or lower), so that\naudio qualtiy is not affected by the meter display."),
+        _("Meter refresh rate per second [1-100]: "),
+        _("Meter Preferences"),
+        mMeterRefreshRate,
+       1,
+       100);
+
+#if defined(__WXMAC__)
+   // WXMAC doesn't support wxFRAME_FLOAT_ON_PARENT, so we do
+   SetWindowClass((WindowRef)d.MacGetWindowRef(), kFloatingWindowClass);
+#endif
+
+   if (d.ShowModal() == wxID_OK) {
+      mMeterRefreshRate = d.GetValue();
+      gPrefs->Write(wxT("/Meter/MeterRefreshRate"), mMeterRefreshRate);
+   }
    
-   mTimer.Start(1000/mMeterRefreshRate);
+   mTimer.Start(1000 / mMeterRefreshRate);
 }
 
 // Indentation settings for Vim and Emacs.
